==> eiffelstudio-18.11.10.2592.tar: F_code/C11/in530.c <==
/*
 * Code for class INH_ASSERT_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in530.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INH_ASSERT_INFO}.make */
void F614_8306 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_NATURAL_64 tu8_1;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (has_replicated_ast) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21215[Dtype(arg1)-2441]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(1048576)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(1048576)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	if (tb1) {
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R21151[Dtype(arg1)-2441])(RTCW(arg1));
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_) = (EIF_INTEGER_32) ti4_1;
	} else {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O20939[Dtype(arg1)-2441]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O20940[Dtype(arg1)-2441]);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_1_) = (EIF_INTEGER_32) ti4_1;
	{
		/* INLINED CODE (has_postcondition) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21215[Dtype(arg1)-2441]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(256)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(256)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) = (EIF_BOOLEAN) tb1;
	{
		/* INLINED CODE (has_precondition) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21215[Dtype(arg1)-2441]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(128)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(128)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_) = (EIF_BOOLEAN) tb1;
	RTLE;
}

/* {INH_ASSERT_INFO}.written_class */
EIF_REFERENCE F614_8307 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(8301,F612_8301,(Current));
	{
		/* INLINED CODE (class_of_id) */
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_);
		tr2 = (EIF_REFERENCE)  0;
		tr3 = tr1;
		tr2 = *(EIF_REFERENCE *)(RTCW(tr3) + _REFACS_37_);
		tr2 = F1536_15054(RTCW(tr2), ti4_1);
		/* END INLINED CODE */
	}
	Result = tr2;
	RTLE;
	return Result;
}

/* {INH_ASSERT_INFO}.has_assertion */
EIF_BOOLEAN F614_8312 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_);
	tb1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (Result || tb1);
	return Result;
}

/* {INH_ASSERT_INFO}.same_as */
EIF_BOOLEAN F614_8313 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_0_1_);
	if ((EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_) == tb2)) {
		tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_0_0_);
		tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) == tb2);
	}
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_2_0_1_);
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_1_) == ti4_1);
	}
	RTLE;
	return Result;
}

void EIF_Minit530 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C11/in530.c <==
/*
 * Code for class INH_ASSERT_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "in530.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {INH_ASSERT_INFO}.make */
void F618_8263 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_NATURAL_64 tu8_1;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	{
		/* INLINED CODE (FEATURE_I.has_replicated_ast) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21385[Dtype(arg1)-2469]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(1048576)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(1048576)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	if (tb1) {
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R21320[Dtype(RTCW(arg1))-2470])(arg1);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_) = (EIF_INTEGER_32) ti4_1;
	} else {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O21106[Dtype(arg1)-2469]);
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_) = (EIF_INTEGER_32) ti4_1;
	}
	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O21107[Dtype(arg1)-2469]);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_1_) = (EIF_INTEGER_32) ti4_1;
	{
		/* INLINED CODE (FEATURE_I.has_postcondition) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21385[Dtype(arg1)-2469]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(256)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(256)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) = (EIF_BOOLEAN) tb1;
	{
		/* INLINED CODE (FEATURE_I.has_precondition) */
		tb1 = (EIF_BOOLEAN)  0;
		tu8_1 = *(EIF_NATURAL_64 *)(RTCW(arg1) + O21385[Dtype(arg1)-2469]);
		tu8_1 = eif_bit_and(tu8_1,((EIF_NATURAL_64) RTU64C(128)));
		tb1 = (EIF_BOOLEAN) (EIF_BOOLEAN)(tu8_1 == ((EIF_NATURAL_64) RTU64C(128)));
		/* END INLINED CODE */
	}
	tb1 = tb1;
	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_) = (EIF_BOOLEAN) tb1;
	RTLE;
}

/* {INH_ASSERT_INFO}.written_class */
EIF_REFERENCE F618_8264 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(5);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,Result);
	RTLIU(5);
	
	RTGC;
	tr1 = RTOSCF(8258,F616_8258, (Current));
	{
		/* INLINED CODE (SYSTEM_I.class_of_id) */
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_0_);
		tr2 = (EIF_REFERENCE)  0;
		tr3 = tr1;
		tr2 = *(EIF_REFERENCE *)(RTCW(tr3) + _REFACS_37_);
		tr2 = F1559_15135(RTCW(tr2), ti4_1);
		/* END INLINED CODE */
	}
	Result = tr2;
	RTLE;
	return Result;
}

/* {INH_ASSERT_INFO}.has_assertion */
EIF_BOOLEAN F618_8269 (EIF_REFERENCE Current)
{
	GTCX
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	
	
	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_);
	tb1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (Result || tb1);
	return Result;
}

/* {INH_ASSERT_INFO}.same_as */
EIF_BOOLEAN F618_8270 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_0_1_);
	if ((EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_0_1_) == tb2)) {
		tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_0_0_);
		tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) == tb2);
	}
	if (tb1) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_0_2_0_1_);
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_0_2_0_1_) == ti4_1);
	}
	RTLE;
	return Result;
}

void EIF_Minit530 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
